@@ -396,18 +396,18 @@ int main(int argc, char* argv[])
         saphire_rehash2();
         char* prompt = getenv("SAPHIRE_PROMPT");
         if(prompt) {
-            string_obj* ret = STRING_NEW("");
+            sWFd* pipeout = WFD_NEW(-1);
             sRFd* rfd = RFD_NEW(0);
-            if(saphire_shell3(ret, prompt, "SAPHIRE_PROMPT", rfd) == -1) {
+            if(saphire_shell3(pipeout, prompt, "SAPHIRE_PROMPT", rfd) == -1) {
                 mreset_tty();
                 buf = readline("> ");
             }
             else {
                 mreset_tty();
-                buf = readline(string_c_str(ret));
+                buf = readline(pipeout->mBuffer);
             }
             sRFd_delete(rfd);
-            string_delete(ret);
+            sWFd_delete(pipeout);
         }
         else {
             mreset_tty();
