@@ -530,7 +530,7 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                         char* src = entry->d_name;
                         int des_size = strlen(src)*2;
                         char* des = MALLOC(des_size);
-                        if(is_all_ascii(src)) {
+                        if(is_all_ascii(kByte, src)) {
                             xstrncpy(des, src, des_size);
                         }
                         else {
@@ -582,7 +582,7 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                         char* src = entry->d_name;
                         int des_size = strlen(src)*2;
                         char* des = MALLOC(des_size);
-                        if(is_all_ascii(src)) {
+                        if(is_all_ascii(kByte, src)) {
                             xstrncpy(des, src, des_size);
                         }
                         else {
@@ -647,7 +647,7 @@ char* readline_file_completion_migemo(const char* text, int rstat)
         }
 
         /// アスキー文字同士の補完 ///
-        else if(is_all_ascii((char*)text2) && is_all_ascii(file)) {
+        else if(is_all_ascii(kByte, (char*)text2) && is_all_ascii(kByte, file)) {
             if(strncmp(text2, file, wordlen) == 0) {
                 char path[PATH_MAX];
                 xstrncpy(path, file, PATH_MAX);
@@ -930,7 +930,7 @@ char* readline_file_completion(const char* text, int rstat)
                         char* src = entry->d_name;
                         int des_size = strlen(src)*2;
                         char* des = MALLOC(des_size);
-                        if(is_all_ascii(src)) {
+                        if(is_all_ascii(kByte, src)) {
                             xstrncpy(des, src, des_size);
                         }
                         else {
@@ -979,7 +979,7 @@ char* readline_file_completion(const char* text, int rstat)
                         char* src = entry->d_name;
                         int des_size = strlen(src)*2;
                         char* des = MALLOC(des_size);
-                        if(is_all_ascii(src)) {
+                        if(is_all_ascii(kByte, src)) {
                             xstrncpy(des, src, des_size);
                         }
                         else {
@@ -1586,12 +1586,12 @@ static int readline_macro(int count, int key)
     xstrncpy(tmp, rl_line_buffer, strlen(rl_line_buffer) +1);
     tmp[rl_point] = 0;
 
-    string_obj* ret = STRING_NEW("");
+    sWFd* pipeout = WFD_NEW(-1);
     sRFd* rfd = RFD_NEW(-1);
     sRFd_set_buffer(rfd, tmp);
     FREE(tmp);
-    if(saphire_shell3(ret, "macro", "SAPHIRE_MACRO", rfd) < 0) {
-        string_delete(ret);
+    if(saphire_shell3(pipeout, "macro", "SAPHIRE_MACRO", rfd) < 0) {
+        sWFd_delete(pipeout);
         sRFd_delete(rfd);
         fprintf(stderr, "run time err\n");
         fprintf(stderr, "%s", string_c_str(gErrMsg));
@@ -1600,9 +1600,9 @@ static int readline_macro(int count, int key)
     }
     sRFd_delete(rfd);
 
-    rl_insert_text(string_c_str(ret));
+    rl_insert_text(pipeout->mBuffer);
 
-    string_delete(ret);
+    sWFd_delete(pipeout);
 
     return 0;
 }
