@@ -181,6 +181,9 @@ sRFd* sRFd_new2(int fd, char* str);
 
 #endif
 
+sRFd* sRFd_new3(int fd, MANAGED char* buffer, int malloc_size);
+#define RFD_NEW3(o, o2, o3) sRFd_new3(o, o2, o3)
+sRFd* sRFd_new_from_wfd(int fd, sWFd* nextout);
 
 void sRFd_delete(sRFd* self);
 BOOL sRFd_close(sRFd* self);
@@ -233,9 +236,8 @@ int saphire_shell(char* command, char* title, sWFd* pipeout, sRFd* pipein, int p
     // 戻り値はプログラムの終了コードだが、0以下だと
     // saphire内でエラーが起こっているのでgErrMsgをどこかに
     // 出力してください。
-int saphire_shell3(string_obj* result, char* command, char* title, sRFd* pipein);
-    // 文字列を読み込んで実行。コマンドの出力はresult
-    // (saphire_string.hで定義されているstring_obj*文字列型)に入る
+int saphire_shell3(sWFd* pipeout, char* command, char* title, sRFd* pipein);
+    // 文字列を読み込んで実行。コマンドの出力はpipeout->mBuffer
     // 戻り値はプログラムの終了コードだが、0以下だとsaphire内でエラーが
     // 起こっている
     // のでgErrMsgをどこかに出力してください。
@@ -445,5 +447,13 @@ void err_msg(char* msg, char* sname, int line);
 extern BOOL gRunningOnTerminal;
     // 端末上で動いているかどうか
 
+/// cancelable
+BOOL vector_sort_cancelable(vector_obj* self, sort_if fun);
+BOOL memcpy_cancelable(char* mem, char* mem2, size_t size);
+BOOL string_put_cancelable(string_obj* self, char* str);
+BOOL string_push_back_cancelable(string_obj* self, char* str);
+string_obj* string_new_cancelable(char* str);
+int str_kanjilen_cancelable(enum eKanjiCode code, char* mbs);
+
 #endif
 
