@@ -15,11 +15,11 @@ enum eCommandKind {
     kSweep, kShow,
     kSubshell, kMSleep, kTrue, kFalse, kTest,
     kIndex, kRIndex, kLength, kLc, kUc,
-    kChomp, kSubstr, kEval, kFg, kBg, 
+    kChomp, kEval, kFg, kBg, 
     kJobs, kRehash, kKanjiCode, kLineField,
     kCalc, kPrint,  kPuts, kLoad, 
     kWhile, kBreak, kExit, kIf, kSplit, kX, kJoin, kSelect, kLines, kRows,
-    kMatch, kScan, kErase, kSub, kGSub, 
+    kMatch, kScan, kSub, kGSub, 
     kRead, kClose, 
     kCd, 
     kAdd, kDel, kSelector, kMax, kMin,
@@ -504,8 +504,8 @@ int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pip
 
 int saphire_shell4(char* command, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, sObject* object);
     // ʸɤ߹Ǽ¹
-int saphire_shell5(string_obj* result, char* command, char* title, sRFd* pipein, sObject* object);
-    // ʸɤ߹Ǽ¹ԡޥɤνϤresult
+int saphire_shell5(sWFd* pipeout, char* command, char* title, sRFd* pipein, sObject* object);
+    // ʸɤ߹Ǽ¹ԡޥɤνϤpipeout->mBuffer
 void saphire_set_global_var2(char* name, char* value, sObject* object);
     // ֥Ȥ°Хѿꤹ
 
