@@ -7,12 +7,12 @@
 #include <string.h>
 #include <stdio.h>
 
-char* gKanjiCodeString[5] = {
-    "eucjp", "sjis", "utf8", "utf8-mac", "unknown"
+char* gKanjiCodeString[6] = {
+    "eucjp", "sjis", "utf8", "utf8-mac", "byte", "unknown"
 };
 
-char* gIconvKanjiCodeName[5] = {
-    "eucjp", "sjis", "utf-8", "utf-8-mac", "unknown"
+char* gIconvKanjiCodeName[6] = {
+    "eucjp", "sjis", "utf-8", "utf-8-mac", "unknown", "unknown"
 };
 
 //////////////////////////////////////////////////////////////////////
@@ -34,7 +34,10 @@ void kanji_final()
 //////////////////////////////////////////////////////////////////////
 int str_termlen_range(enum eKanjiCode code, char* mbs, int utfpos1, int utfpos2)
 {
-    if(code == kUtf8) {
+    if(code == kByte) {
+        return utfpos2 - utfpos1;
+    }
+    else if(code == kUtf8) {
         if(is_utf8_bytes(mbs)) {
             if(utfpos1 < utfpos2) {
                 char* putfpos1 = str_kanjipos2pointer(kUtf8, mbs, utfpos1);
@@ -118,6 +121,9 @@ int str_pointer2kanjipos(enum eKanjiCode code, char* mbs, char* point)
 
         return result;
     }
+    else if(code == kByte) {
+        return point - mbs;
+    }
     else {
         char* mbs2;
         int result;
@@ -167,6 +173,9 @@ char* str_kanjipos2pointer(enum eKanjiCode code, char* mbs, int pos)
 
         return mbs + strlen(mbs);
     }
+    else if(code == kByte) {
+        return mbs + pos;
+    }
     else {
         if(pos<0) return mbs;
 
@@ -197,7 +206,10 @@ char* str_kanjipos2pointer(enum eKanjiCode code, char* mbs, int pos)
 //////////////////////////////////////////////////////////////////////
 int str_kanjilen(enum eKanjiCode code, char* mbs)
 {
-    if(code == kUtf8) {
+    if(code == kByte) {
+        return strlen(mbs);
+    }
+    else if(code == kUtf8) {
         int n = 0;
         char* p = mbs;
 
@@ -212,11 +224,6 @@ int str_kanjilen(enum eKanjiCode code, char* mbs)
                 p++;
                 n++;
             }
-/*
-if(gKitutukiSigInt) {
-    return -1;
-}
-*/
         }
 
         return n;
@@ -271,14 +278,20 @@ int is_kanji(enum eKanjiCode code, unsigned char c)
 //////////////////////////////////////////////////////////////////////
 // FALSE:漢字まじり TRUE:全部英数字
 //////////////////////////////////////////////////////////////////////
-int is_all_ascii(char* buf)
+int is_all_ascii(enum eKanjiCode code, char* buf)
 {
-    char* p = buf;
-    while(*p) {
-        if(((unsigned char)*p) > 127) {
-            return FALSE;
+    if(code == kUtf8 || code == kByte) {
+        char* p = buf;
+        while(*p) {
+            if(((unsigned char)*p) > 127) {
+                return FALSE;
+            }
+            p++;
         }
-        p++;
+    }
+    else if(code == kSjis || code == kEucjp) {
+        fprintf(stderr, "unexpected err in is_all_ascii\n");
+        exit(1);
     }
 
     return TRUE;
@@ -367,7 +380,7 @@ int kanji_convert(char* input_buf, char* output_buf, size_t output_buf_size, enu
         xstrncpy(output_buf, input_buf, output_buf_size);
     }
     else {
-        if(is_all_ascii(input_buf)
+        if(is_all_ascii(kByte, input_buf)
             || input_kanji_encode_type == output_kanji_encode_type
             || input_kanji_encode_type < 0
             || input_kanji_encode_type >= kUnknown 
