@@ -36,6 +36,11 @@ static BOOL read_until_next_close_character(char first_char, char last_char, cha
         BOOL squote = FALSE;
         BOOL dquote = FALSE;
         while(1) {
+            if(gKitutukiSigInt) {
+                err_msg("signal interrupt", sname, *sline);
+                gKitutukiSigInt = FALSE;
+                return FALSE;
+            }
             /// クォート ///
             if(!squote && !dquote && **p == '\\') {
                 string_push_back2(not_evaled, **p);
@@ -1930,22 +1935,22 @@ BOOL expand_env(char* p, string_obj* out, sRFd* rfd, char* sname, int* sline, sO
                 string_erase(str, 0, 1); // (をとる
                 string_trunc(str, string_length(str)-1); // )をとる
 
-                string_obj* ret = STRING_NEW("");
+                sWFd* pipeout = WFD_NEW(-1);
                 char* fname = MALLOC(strlen(sname) + 256);
                 snprintf(fname, strlen(sname) + 256, "%s %d: expand command", sname, *sline);
-                int rcode = saphire_shell5(ret, string_c_str(str), fname, rfd, object);
+                int rcode = saphire_shell5(pipeout, string_c_str(str), fname, rfd, object);
                 FREE(fname);
                 string_delete(str);
                 if(rcode < 0) {
-                    string_delete(ret);
+                    sWFd_delete(pipeout);
                     return FALSE;
                 }
 
                 if(quote) {
                     string_obj* quoted = STRING_NEW("");
-                    if(!expand_env_get_quoted_str(string_c_str(ret), quoted, sname, sline))
+                    if(!expand_env_get_quoted_str(pipeout->mBuffer, quoted, sname, sline))
                     {
-                        string_delete(ret);
+                        sWFd_delete(pipeout);
                         string_delete(quoted);
                         return FALSE;
                     }
@@ -1953,10 +1958,10 @@ BOOL expand_env(char* p, string_obj* out, sRFd* rfd, char* sname, int* sline, sO
                     string_delete(quoted);
                 }
                 else {
-                    string_push_back(out, string_c_str(ret));
+                    string_push_back(out, pipeout->mBuffer);
                 }
 
-                string_delete(ret);
+                sWFd_delete(pipeout);
             }
             else {
                 string_push_back2(out, *p++);
